==> dev-common-1.0.19.tgz: package/src/utils/remote-content-source.ts <==
import { URL } from 'url';
import crypto from 'crypto';
import axios from 'axios';
import { Logger } from '@stackbit/types';
import { getCommandRunner } from '@stackbit/cms-core';

export type Extension = {
    id: number;
    integrationName: string;
    integrationSlug: string;
    lightLogoPath: string;
    darkLogoPath: string;
    createdAt: string;
    updatedAt: string;
    teamInstallationId: number;
    siteId: string;
    dataLayerId: string;
    configurationType: 'create';
    config: Record<string, string>;
    sourceUrl: string;
    name: string;
    hostSiteUrl: string;
    prefix: string;
};

type GetContentSourceParams = {
    siteId: string;
    teamId: string;
    netlifyAccessToken?: string;
    projectId?: string;
    apiSecret?: string;
    logger: Logger;
    baseURL: string;
};

export const getRemoteContentSources = async ({ siteId, teamId, projectId, netlifyAccessToken, apiSecret, logger, baseURL }: GetContentSourceParams) => {
    try {
        const headers: Record<string, string> = {
            'Content-Type': 'application/json',
            Authorization: `Bearer ${apiSecret ?? netlifyAccessToken}`
        };
        let urlPath = 'core/site-extensions-config';

        if (netlifyAccessToken) {
            headers['x-nf-request-id'] = crypto.randomBytes(16).toString('hex');
        } else {
            urlPath = `${urlPath}/${projectId}`;
        }

        const url = new URL(urlPath, baseURL);
        url.searchParams.set('configuration_type', 'create');
        url.searchParams.set('site_id', siteId);
        url.searchParams.set('team_id', teamId);
        const response = await axios<Extension[]>(url.toString(), { headers });
        return response.data;
    } catch (error) {
        logger.debug('Error fetching remote content sources', { error });
        return [];
    }
};

export const installRemoteContentSources = async ({
    extensions,
    rootDir,
    logger
}: {
    extensions: Extension[];
    rootDir: string;
    logger: Logger;
}): Promise<{ path: string; id: number; config: Record<string, unknown> }[]> => {
    const modulesToInstall = extensions.map((extension, index) => `${extension.integrationSlug}-connector@${extension.sourceUrl}?v=${Math.random()}-${index}`);
    const result = extensions.map((extension) => ({
        id: extension.id,
        config: extension.config,
        path: `${rootDir}/.stackbit/.cache/remote-content-sources/node_modules/${extension.integrationSlug}-connector/netlify-create.js`
    }));

    const runCommand = getCommandRunner({ env: process.env });
    try {
        await runCommand('npm', ['install', ...modulesToInstall, '--no-save', '--prefix', '.stackbit/.cache/remote-content-sources', '--exact'], {
            env: process.env,
            cwd: rootDir,
            logger
        });

        return result;
    } catch (error) {
        logger.error(`Error installing remote content sources: ${modulesToInstall.join(',')}`, error);
        return [];
    }
};

==> dev-common-1.0.22.tgz: package/src/utils/remote-content-source.ts <==
import { URL } from 'url';
import crypto from 'crypto';
import axios from 'axios';
import { Logger } from '@stackbit/types';
import { getCommandRunner } from '@stackbit/cms-core';

export type Extension = {
    id: number;
    integrationName: string;
    integrationSlug: string;
    lightLogoPath: string;
    darkLogoPath: string;
    createdAt: string;
    updatedAt: string;
    teamInstallationId: number;
    siteId: string;
    dataLayerId: string;
    configurationType: 'create';
    config: Record<string, string>;
    sourceUrl: string;
    name: string;
    hostSiteUrl: string;
    prefix: string;
};

type GetContentSourceParams = {
    siteId: string;
    teamId: string;
    netlifyAccessToken?: string;
    projectId?: string;
    apiSecret?: string;
    logger: Logger;
    baseURL: string;
};

export const getRemoteContentSources = async ({ siteId, teamId, projectId, netlifyAccessToken, apiSecret, logger, baseURL }: GetContentSourceParams) => {
    try {
        const headers: Record<string, string> = {
            'Content-Type': 'application/json',
            authorization: `Bearer ${apiSecret ?? netlifyAccessToken}`
        };
        let urlPath = 'core/site-extensions-config';

        if (netlifyAccessToken) {
            headers['x-nf-request-id'] = crypto.randomBytes(16).toString('hex');
        } else {
            urlPath = `${urlPath}/${projectId}`;
        }

        const url = new URL(urlPath, baseURL);
        url.searchParams.set('configuration_type', 'create');
        url.searchParams.set('site_id', siteId);
        url.searchParams.set('team_id', teamId);
        const response = await axios<Extension[]>(url.toString(), { headers });
        return response.data;
    } catch (error) {
        logger.debug('Error fetching remote content sources', { error });
        return [];
    }
};

export const installRemoteContentSources = async ({
    extensions,
    rootDir,
    logger
}: {
    extensions: Extension[];
    rootDir: string;
    logger: Logger;
}): Promise<{ path: string; id: number; config: Record<string, unknown> }[]> => {
    const modulesToInstall = extensions.map((extension, index) => `${extension.integrationSlug}-connector@${extension.sourceUrl}?v=${Math.random()}-${index}`);
    const result = extensions.map((extension) => ({
        id: extension.id,
        config: extension.config,
        path: `${rootDir}/.stackbit/.cache/remote-content-sources/node_modules/${extension.integrationSlug}-connector/netlify-create.js`
    }));

    const runCommand = getCommandRunner({ env: process.env });
    try {
        await runCommand('npm', ['install', ...modulesToInstall, '--no-save', '--prefix', '.stackbit/.cache/remote-content-sources', '--exact'], {
            env: process.env,
            cwd: rootDir,
            logger
        });

        return result;
    } catch (error) {
        logger.error(`Error installing remote content sources: ${modulesToInstall.join(',')}`, error);
        return [];
    }
};
